<div align="center">
  <h1>
    <br/>
    <img src="../../../img/claritygenie_logo.jpg" alt="claritygenie_logo" width="60"/>
    <br/>
    ClarityGenie
  </h1>
</div>

- [Description](#description)
- [Run ClarityGenie User Interface](#claritygenieui)
- [About RQle.AI](#about-rqle-ai)
- [Related Materials](#related-material)
- [Disclaimer](#disclaimer)

## Description <a name="description"></a>
Prompt engineering is the art of crafting instructions to get the most out of generative AI models. By designing 
specific prompts, you can steer the AI towards generating the desired creative text formats, translating languages, 
or writing different kinds of creative content

**RQle.AI** is introducing **ClarityGenie** as your one-stop shop for crafting powerful prompts through revision and 
refinement by a Large Language Model (LLM). This is accomplished by:
* **Enhanced Clarity**: ClarityGenie analyzes your input prompt and suggests improvements, ensuring your AI tools 
  understand your intent perfectly.
* **Context is King**: ClarityGenie helps you provide the context AI needs to deliver exceptional results, 
  tailored exactly to your vision.

ClarityGenie return its output in [Markdown](https://www.markdownguide.org/getting-started/), which has been known to 
yield better results than plain text.

## Run ClarityGenie User Interface <a name="claritygenieui"></a>
To start the User Interface (UI) for ClarityGenie, the following command should be executed
```
 streamlit run .\rqle_ai_langchain_util\examples\clarity_genie\clarity_genie_ui.py
```

## About RQle.AI <a name="about-rqle-ai"></a>
[**RQle.AI**](https://www.linkedin.com/company/102641077) believes in the transformative potential of Generative AI. More specifically, it focuses on showcasing 
real-world applications of how Generative AI can empower individuals and organizations worldwide in addressing customers' 
"*job to be done*" problems and create value for them.

## Related Materials <a name="related-material"></a>

## Disclaimer <a name="disclaimer"></a>
This application was partially generated by a large language model (Generative AI). While the AI assisted in the 
generation of ideas and content, the final solution and its implementation remain the responsibility of the human user. 
It is important to critically evaluate and revise the AI-generated content to ensure its accuracy, appropriateness, 
and ethical implications.

<div style="text-align: center;">
  <hr/>
  <img src="../../../img/rqle_ai_logo_alt.jpeg" alt="RQle.AI" width="60"/>
  &nbsp; RQle.AI - 2024
</div>